Method: Binance::Client::WebSocket#agg_trade
- Defined in:
- lib/binance/client/websocket.rb
#agg_trade(symbol:, methods:) ⇒ Object
Public: Create an Aggregate Trade stream
:symbol - The String symbol the stream will listen to
:methods - The Hash which contains the event handler methods to pass to
the WebSocket client
:open - The Proc called when a stream is opened (optional)
:message - The Proc called when a stream receives a
:error - The Proc called when a stream receives an error (optional)
:close - The Proc called when a stream is closed (optional)
60 61 62 |
# File 'lib/binance/client/websocket.rb', line 60 def agg_trade(symbol:, methods:) single stream: { symbol: symbol, type: 'aggTrade' }, methods: methods end |