Method: Binance::Client::WebSocket#all_market_ticker

Defined in:
lib/binance/client/websocket.rb

#all_market_ticker(methods:) ⇒ Object

Public: Create a Ticker stream for all symbols

:methods - The Hash which contains the event handler methods to pass to

         the WebSocket client
:open    - The Proc called when a stream is opened (optional)
:message - The Proc called when a stream receives a message
:error   - The Proc called when a stream receives an error (optional)
:close   - The Proc called when a stream is closed (optional)


119
120
121
# File 'lib/binance/client/websocket.rb', line 119

def all_market_ticker(methods:)
  single stream: { symbol: '!ticker', type: 'arr' }, methods: methods
end