Method: Binance::Client::WebSocket#diff_depth

Defined in:
lib/binance/client/websocket.rb

#diff_depth(symbol:, methods:) ⇒ Object

Public: Create a Diff Depth stream

:symbol - The String symbol the stream will listen to

:methods - The Hash which contains the event handler methods to pass to

         the WebSocket client
:open    - The Proc called when a stream is opened (optional)
:message - The Proc called when a stream receives a message
:error   - The Proc called when a stream receives an error (optional)
:close   - The Proc called when a stream is closed (optional)


151
152
153
# File 'lib/binance/client/websocket.rb', line 151

def diff_depth(symbol:, methods:)
  single stream: { symbol: symbol, type: 'depth' }, methods: methods
end