Method: Binance::Client::WebSocket#partial_book_depth

Defined in:
lib/binance/client/websocket.rb

#partial_book_depth(symbol:, level:, methods:) ⇒ Object

Public: Create an Partial Book Depth stream

:symbol - The String symbol the stream will listen to

:level - The String interval the stream will update with. The intervals

that may be used can be found in the Binance API docs.

:methods - The Hash which contains the event handler methods to pass to

         the WebSocket client
:open    - The Proc called when a stream is opened (optional)
:message - The Proc called when a stream receives a message
:error   - The Proc called when a stream receives an error (optional)
:close   - The Proc called when a stream is closed (optional)


136
137
138
139
# File 'lib/binance/client/websocket.rb', line 136

def partial_book_depth(symbol:, level:, methods:)
  single stream: { symbol: symbol, type: 'depth', level: level },
         methods: methods
end